@@ -736,7 +736,7 @@ TQObject::~TQObject()
     }
     if ( parentObj )				// remove it from parent object
 	parentObj->removeChild( this );
-    register TQObject *obj;
+    TQObject *obj;
     if ( senderObjects ) {			// disconnect from senders
 	TQSenderObjectList *tmp = senderObjects;
 	senderObjects = 0;
@@ -753,7 +753,7 @@ TQObject::~TQObject()
 	    TQConnectionList* clist = (*connections)[i]; // for each signal...
 	    if ( !clist )
 		continue;
-	    register TQConnection *c;
+	    TQConnection *c;
 	    TQConnectionListIt cit(*clist);
 	    while( (c=cit.current()) ) {	// for each connected slot...
 		++cit;
@@ -879,7 +879,7 @@ void *tqt_inheritedBy( TQMetaObject *superClass, const TQObject *object )
 {
     if (!object)
 	return 0;
-    register TQMetaObject *mo = object->metaObject();
+    TQMetaObject *mo = object->metaObject();
     while (mo) {
 	if (mo == superClass)
 	    return (void*)object;
@@ -1266,7 +1266,7 @@ bool TQObject::activate_filters( TQEvent *e )
     if ( !eventFilters )			// no event filter
 	return FALSE;
     TQObjectListIt it( *eventFilters );
-    register TQObject *obj = it.current();
+    TQObject *obj = it.current();
     while ( obj ) {				// send to all filters
 	++it;					//   until one returns TRUE
 	if ( obj->eventFilter(this,e) ) {
@@ -2466,7 +2466,7 @@ bool TQObject::disconnectInternal( const TQObject *sender, int signal_index,
 
     bool success = FALSE;
     TQConnectionList *clist;
-    register TQConnection *c;
+    TQConnection *c;
     if ( signal_index == -1 ) {
 	for ( int i = 0; i < (int) s->connections->size(); i++ ) {
 	    clist = (*s->connections)[i]; // for all signals...
@@ -3060,7 +3060,7 @@ void TQObject::dumpObjectInfo()
 	    if ( ( clist = connections->at( i ) ) ) {
 		tqDebug( "\t%s", metaObject()->signal( i, TRUE )->name );
 		n++;
-		register TQConnection *c;
+		TQConnection *c;
 		TQConnectionListIt cit(*clist);
 		while ( (c=cit.current()) ) {
 		    ++cit;
