@@ -733,7 +733,7 @@ public:
     void remove( iterator it ) { detach(); sh->remove( it ); }
     void remove( const Key& k );
 
-#if defined(Q_FULL_TEMPLATE_INSTANTIATION)
+#if defined(TQ_FULL_TEMPLATE_INSTANTIATION)
     bool operator==( const TQMap<Key,T>& ) const { return FALSE; }
 #ifndef QT_NO_STL
     bool operator==( const std::map<Key,T>& ) const { return FALSE; }
