@@ -597,7 +597,7 @@ TQAction::~TQAction()
 */
 void TQAction::setIconSet( const TQIconSet& icon )
 {
-    register TQIconSet *i = d->iconset;
+    TQIconSet *i = d->iconset;
     if ( !icon.isNull() )
 	d->iconset = new TQIconSet( icon );
     else
